summaryrefslogtreecommitdiffstats
path: root/powermanager
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-24 13:26:54 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-24 13:26:54 -0600
commit4066d7fb18b31353b86afa9fc1d94d492008e733 (patch)
tree4b4b8888abd5cd6523601b770b188927d259d8e6 /powermanager
parent3a80ef8a0d25cc90b92b41dccd698b5d7ec9dc13 (diff)
downloadtde-guidance-4066d7fb18b31353b86afa9fc1d94d492008e733.tar.gz
tde-guidance-4066d7fb18b31353b86afa9fc1d94d492008e733.zip
Rename KGlobal, KProcess, and KClipboard to avoid conflicts with KDE4
Diffstat (limited to 'powermanager')
-rwxr-xr-xpowermanager/guidance-power-manager.py10
1 files changed, 5 insertions, 5 deletions
diff --git a/powermanager/guidance-power-manager.py b/powermanager/guidance-power-manager.py
index 0edeedb..1f25691 100755
--- a/powermanager/guidance-power-manager.py
+++ b/powermanager/guidance-power-manager.py
@@ -81,7 +81,7 @@ class PowerManager(PowerManagerUI):
def __init__ (self, parent, name):
PowerManagerUI.__init__(self, parent, name)
- KGlobal.iconLoader().addAppDir("guidance")
+ TDEGlobal.iconLoader().addAppDir("guidance")
# The systray icon should show and hide the KDialogBase, not only this widget,
# therefore, it gets our parent as parent.
@@ -336,9 +336,9 @@ class PowerManager(PowerManagerUI):
menu.insertItem(i18n("CPU policy"), submenu)
# KGlobalAccel crashes the application in pytde
# see http://mats.gmd.de/pipermail/pytde/2006-May/013224.html
- #self.globalActions = KGlobalAccel(self)
+ #self.globalActions = TDEGlobalAccel(self)
#self.suspendShortcut = KShortcut("XF86Sleep")
#self.hibernateShortcut = KShortcut("XF86Standby")
#self.hshutdownShortcut = KShortcut("XF86PowerOff")
@@ -1042,8 +1042,8 @@ class PowermanagerApp(KDialogBase):
def __init__(self,parent=None,name=None):
""" Initialise dialog and set mainwidget. """
- KGlobal.locale().insertCatalogue("guidance")
- KGlobal.iconLoader().addAppDir("guidance")
+ TDEGlobal.locale().insertCatalogue("guidance")
+ TDEGlobal.iconLoader().addAppDir("guidance")
# We would like to use a KUniqueApplication, but that breaks dcop due to some
# strange bug. The following line is the revenge code for this bug, it is
@@ -336,9 +336,9 @@ class PowerManager(PowerManagerUI):
menu.insertItem(i18n("CPU policy"), submenu)
- # KGlobalAccel crashes the application in pytde
+ # TDEGlobalAccel crashes the application in pytde
# see http://mats.gmd.de/pipermail/pytde/2006-May/013224.html